from fastapi import APIRouter, Depends, HTTPException, Query
from sqlalchemy.orm import Session
from typing import Any, Optional

from app import crud
from app.api import deps

from app.schemas.lesson import LessonSearchResults
from app.models.user import User

router = APIRouter()


@router.get(
    "/search/", 
    status_code=200,
    response_model=LessonSearchResults)
def search_lessons(
    tag: Optional[str] = Query(
        None, 
        min_length=3, 
        example="tech"), 
    max_results: Optional[int] = 10,
    db: Session = Depends(deps.get_db),
    current_user: User = Depends(deps.get_current_user),
    ) -> dict:
    """
    Search for lessons based on tags
    """
    
    lessons = crud.lesson.get_multi(db=db, limit=max_results)
    
    if not tag:
        # We use Python list slicing to limit results
        # based on the max_results query parameter
        return {"results": lessons} 

    results = filter(
        lambda lesson: tag.lower() in lesson.tags.split(", "), 
        lessons)

    return {"results": list(results)}
