import os
from typing import Optional

from pathlib import Path

from fastapi import (
    FastAPI, 
    APIRouter,
    Query,
    HTTPException,
    Request,
    Depends,
)

from fastapi.middleware.cors import CORSMiddleware

from fastapi.templating import Jinja2Templates

from sqlalchemy.orm import Session

from app.api import deps

from app import crud

from app.db.lessons_data import LESSONS

from app.api.api_v1.api import api_router
from app.core.config import settings

BASE_PATH = Path(__file__).resolve().parent
TEMPLATES = Jinja2Templates(
    directory=os.path.join(BASE_PATH, "templates"))

root_router = APIRouter()

app = FastAPI(
    title="Lessons Learned API", 
    openapi_url="/openapi.json"
)

# Set all CORS enabled origins
if settings.BACKEND_CORS_ORIGINS:
    app.add_middleware(
        CORSMiddleware,
        allow_origins=[str(origin) for origin in settings.BACKEND_CORS_ORIGINS],
        allow_credentials=True,
        allow_methods=["*"],
        allow_headers=["*"],
    )


@root_router.get("/", status_code=200)
def root(
    request: Request,
    db: Session = Depends(deps.get_db),
    ) -> dict:
    """
    Root Get
    """
    
    lessons = crud.lesson.get_multi(db=db, limit=10)
    
    return TEMPLATES.TemplateResponse(
        "index.html",
        {
            "request": request, 
            "lessons": lessons,
            },
    )


app.include_router(api_router, prefix=settings.API_V1_STR)
app.include_router(root_router)


if __name__ == "__main__":
    import uvicorn
    uvicorn.run(app, host="0.0.0.0", port=8001, log_level="debug")
