from uuid import uuid4

import pytest

from app.core.config import settings


HOST = 'http://0.0.0.0:8001'


def test_signup(client):
    # When
    test_url = f"{HOST}{settings.API_V1_STR}/auth/signup"

    response = client.post(
        test_url, 
        headers={
            'accept': 'application/json',
            'Authorization': f'bearer {pytest.token}',
            'Content-Type': 'application/json'
            },
        json={
            "first_name": "Alan",
            "surname": "Kay",
            "email": f"alan{uuid4()}@isthebest.org",
            "is_superuser": False,
            "password": "power_of_simplicity"
            })

    data = response.json()
    assert response.status_code == 201


def test_login(client):
    test_url = f"{HOST}{settings.API_V1_STR}/auth/login"

    response = client.post(
        test_url, 
        data={
            'grant_type': None,
            'username': 'cst@ctrl-c.club',
            'password': 'PEACEandLOVE',
            'scope': None,
            'client_id': None,
            'client_secret': None,
            })

    pytest.token = response.json()['access_token']

    assert response.status_code == 200


def test_me(client):
    # When
    test_url = f"{HOST}{settings.API_V1_STR}/auth/me"
    print(test_url)
    response = client.get(
        test_url, 
        headers={
            'accept': 'application/json',
            'Authorization': f'bearer {pytest.token}',
            'Content-Type': 'application/json'
            })

    data = response.json()

    assert response.status_code == 200


def test_fetch_lesson(client):
    LESSON_ID = 1
    
    # When
    test_url = f"{HOST}{settings.API_V1_STR}/lesson/{LESSON_ID}"

    response = client.get(
        test_url, 
        headers={
            'accept': 'application/json',
            'Authorization': f'bearer {pytest.token}',
            })

    data = response.json()

    # Then
    assert response.status_code == 200


def test_create_lesson(client):
    # When
    test_url = f"{HOST}{settings.API_V1_STR}/lesson/"
    print('fetched token', pytest.token)
    response = client.post(
        test_url, 
        headers={
            'accept': 'application/json',
            'Authorization': f'bearer {pytest.token}',
            'Content-Type': 'application/json'
            },
        json={
            "title": "Host your gemini capsule at a pubnix",
            "content": "The value of pubnix is tremendous. Yes, it will host your gemini capsule, but more importantly it will give you that special feel.",
            "tags": "gemini, pubnix",
            "submitter_id": 1,
            })

    data = response.json()

    # Then
    assert response.status_code == 201



def test_search_lessons(client):
    # When
    test_url = f"{HOST}{settings.API_V1_STR}/search/?tag=tech&max_results=10"
    print(test_url)
    response = client.get(
        test_url, 
        headers={
            'accept': 'application/json',
            'Authorization': f'bearer {pytest.token}',
            })

    data = response.json()

    # Then
    assert response.status_code == 200


def test_get_all_lessons(client):
    LESSON_ID = 1
    
    # When
    test_url = f"{HOST}{settings.API_V1_STR}/lesson/"

    response = client.get(
        test_url, 
        headers={
            'accept': 'application/json',
            'Authorization': f'bearer {pytest.token}',
            })

    data = response.json()

    # Then
    assert response.status_code == 200
