from typing import Generator
from unittest.mock import MagicMock
from fastapi import Depends, HTTPException, status
import pytest
from fastapi.testclient import TestClient

from sqlalchemy.orm.session import Session

from app.main import app
from app.api import deps
from app.models.user import User


def token_plugin():
    return None


def token_user_id():
    # On db create is created a user with id=1.
    # It is used as initialization value here.
    return 1


def pytest_configure():
    pytest.token = token_plugin() 
    pytest.user_id = token_user_id()


async def get_current_user(
    db: Session = Depends(deps.get_db), 
    ) -> User:
    
    user = db.query(User).filter(User.id == 1).first()
    if user is None:
        raise ValueError('User not found')
    return user


# It could override authentication
# and always returns user with id=1
# if you uncomment below
@pytest.fixture
def client() -> Generator:
    with TestClient(app) as client:
        # app.dependency_overrides[deps.get_current_user] = get_current_user
        yield client
        # app.dependency_overrides = {}
